@@ -1,4 +1,4 @@
-"""mssdk 是基于 Python 的为麦思多维科技客户服务的专用API接口"""
+"""mssdk 是基于 Python 的为麦思多维科技客户服务的专用 API 接口"""
 
 """
 0.0.1: 发布测试版本 v0.0.1
@@ -7,9 +7,10 @@
 0.0.4: 发布测试版本 v0.0.4
 0.0.5: 发布测试版本 v0.0.5
 0.0.6: 发布测试版本 v0.0.6
+0.0.7: 发布测试版本 v0.0.7
 """
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 __author__ = 'mssdk'
 
 """
@@ -667,11 +668,6 @@ from mssdk.futures_derivative.nh_index_volatility import nh_volatility_index
 """
 from mssdk.air.air_hebei import air_quality_hebei
 
-"""
-timeanddate-日出和日落
-"""
-from mssdk.air.time_and_date import sunrise_daily, sunrise_monthly
-
 """
 金十财经-实时监控
 """
